@@ -21,17 +21,4 @@ def generate_routes(directory):
     with open(filename, 'w') as f:
         f.write(_routes)
     print "Injecting route dependency"
-    update_dependencies(directory, 'ngRoute')
-
-if __name__ == '__main__':
-    generate_routes('../..')
-
-
-
-
-
-
-
-
-
-
+    update_dependencies(directory, 'ngRoute')
\ No newline at end of file
